import fs from 'fs';
import path from 'path';
export function rollupPluginDependencyStats(cb) {
    let outputDir;
    let cache = {};
    let output = {
        direct: {},
        common: {},
    };
    function buildCache(bundle) {
        for (let fileName of Object.keys(bundle)) {
            const filePath = path.join(outputDir, fileName);
            if (fs.existsSync(filePath)) {
                const { size } = fs.statSync(filePath);
                cache[fileName] = size;
            }
        }
    }
    function compareDependencies(files, type) {
        for (let file of files) {
            const filePath = path.join(outputDir, file);
            const { size } = fs.statSync(filePath);
            output[type][file] = {
                fileName: path.basename(file),
                size,
            };
            if (cache[file]) {
                const delta = (size - cache[file]) / 1000;
                output[type][file].delta = delta;
            }
        }
    }
    return {
        generateBundle(options, bundle) {
            outputDir = options.dir;
            buildCache(bundle);
        },
        writeBundle(bundle) {
            const files = Object.keys(bundle);
            const [directDependencies, commonDependencies] = files.reduce(([direct, common], fileName) => fileName.startsWith('common')
                ? [direct, [...common, fileName]]
                : [[...direct, fileName], common], [[], []]);
            compareDependencies(directDependencies, 'direct');
            compareDependencies(commonDependencies, 'common');
            cb(output);
        },
    };
}
